@@ -136,6 +136,7 @@ dlg_extract__start_ripping (GtkWidget *dialog)
 		    file_format,
 		    goo_player_cd_get_album (data->player_cd),
 		    goo_player_cd_get_artist (data->player_cd),
+		    goo_player_get_year (GOO_PLAYER (data->player_cd)),
 		    goo_player_cd_get_genre (data->player_cd),
 		    g_list_length (data->songs),
 		    tracks_to_rip);
@@ -243,7 +244,7 @@ destination_button_clicked_cb (GtkWidget  *button,
 						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 						NULL);
 	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
-	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (file_sel), TRUE);
+	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (file_sel), FALSE);
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_sel), gtk_entry_get_text (GTK_ENTRY (data->e_destination_entry)));
 
 	g_signal_connect (G_OBJECT (file_sel),
